pub trait Vector<T> {
// Required methods
fn len(&self) -> u32;
fn as_ptr(&self) -> *const T;
fn as_mut_ptr(&mut self) -> *mut T;
// Provided methods
fn inc(&self) -> u32 { ... }
fn is_empty(&self) -> bool { ... }
}Expand description
Methods that allow a type to be used in BLAS functions as a vector.
Required Methods
Sourcefn as_mut_ptr(&mut self) -> *mut T
fn as_mut_ptr(&mut self) -> *mut T
An unsafe mutable pointer to a contiguous block of memory.
Provided Methods